# Inputs

- System parameters file defining the network
    - Including GHE parameters
- Folder of OpenStudio building loads for the network to supply
- Geojson file describing the features (buildings, borefields, connectors, etc) and their locations

See the [usage](usage.md) page for an example
